summaryrefslogtreecommitdiffstats
path: root/Bugzilla/Token.pm
diff options
context:
space:
mode:
authorjustdave%syndicomm.com <>2004-03-18 18:01:34 +0100
committerjustdave%syndicomm.com <>2004-03-18 18:01:34 +0100
commitcbef267df28e3befd53e6982773558c5acafd661 (patch)
tree4608175dea3771c4060cc9a09ac6c7d4f8d8b535 /Bugzilla/Token.pm
parent786d40c197f497ee9d3fa5b92834c0249f20a61b (diff)
downloadbugzilla-cbef267df28e3befd53e6982773558c5acafd661.tar.gz
bugzilla-cbef267df28e3befd53e6982773558c5acafd661.tar.xz
Bug 237864: clean up leftovers from the bug 192516 checkin (some occurances of Token got missed)
r= gerv, a= justdave
Diffstat (limited to 'Bugzilla/Token.pm')
-rw-r--r--Bugzilla/Token.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/Bugzilla/Token.pm b/Bugzilla/Token.pm
index 20ce48050..d7d326ccc 100644
--- a/Bugzilla/Token.pm
+++ b/Bugzilla/Token.pm
@@ -26,7 +26,7 @@
# Make it harder for us to do dangerous things in Perl.
use strict;
# Bundle the functions in this file together into the "Token" package.
package Bugzilla::Token;
use Bugzilla::Config;
@@ -247,7 +247,7 @@ sub DeletePasswordTokens {
"WHERE userid=? AND tokentype='password'");
$sth->execute($userid);
while (my $token = $sth->fetchrow_array) {
- Token::Cancel($token, $reason);
+ Bugzilla::Token::Cancel($token, $reason);
}
}
@@ -26,7 +26,7 @@
# Make it harder for us to do dangerous things in Perl.
use strict;
-# Bundle the functions in this file together into the "Token" package.
+# Bundle the functions in this file together into the "Bugzilla::Token" package.
package Bugzilla::Token;
use Bugzilla::Config;